@@ -9,6 +9,7 @@ import operator
 import re
 import six
 import sys
+import warnings
 
 from collections import OrderedDict
 from functools import wraps, partial
@@ -143,10 +144,10 @@ class Api(object):
         self._default_error_handler = None
         self.tags = tags or []
 
-        self.error_handlers = {
+        self.error_handlers = OrderedDict({
             ParseError: mask_parse_error_handler,
             MaskError: mask_error_handler,
-        }
+        })
         self._schema = None
         self.models = {}
         self._refresolver = None
@@ -219,6 +220,7 @@ class Api(object):
         else:
             self.blueprint = app
 
+
     def _init_app(self, app):
         """
         Perform initialization actions with the given :class:`flask.Flask` object.
@@ -248,6 +250,17 @@ class Api(object):
         )
         app.config.setdefault("RESTX_MASK_HEADER", "X-Fields")
         app.config.setdefault("RESTX_MASK_SWAGGER", True)
+        app.config.setdefault("RESTX_INCLUDE_ALL_MODELS", False)
+
+        # check for deprecated config variable names
+        if "ERROR_404_HELP" in app.config:
+            app.config['RESTX_ERROR_404_HELP'] = app.config['ERROR_404_HELP']
+            warnings.warn(
+                "'ERROR_404_HELP' config setting is deprecated and will be "
+                "removed in the future. Use 'RESTX_ERROR_404_HELP' instead.",
+                DeprecationWarning
+            )
+
 
     def __getattr__(self, name):
         try:
@@ -502,11 +515,11 @@ class Api(object):
     @property
     def specs_url(self):
         """
-        The Swagger specifications absolute url (ie. `swagger.json`)
+        The Swagger specifications relative url (ie. `swagger.json`)
 
         :rtype: str
         """
-        return url_for(self.endpoint("specs"), _external=True)
+        return url_for(self.endpoint("specs"))
 
     @property
     def base_url(self):
@@ -546,7 +559,7 @@ class Api(object):
 
     @property
     def _own_and_child_error_handlers(self):
-        rv = {}
+        rv = OrderedDict()
         rv.update(self.error_handlers)
         for ns in self.namespaces:
             for exception, handler in six.iteritems(ns.error_handlers):
@@ -708,7 +721,7 @@ class Api(object):
 
         elif (
             code == HTTPStatus.NOT_FOUND
-            and current_app.config.get("ERROR_404_HELP", True)
+            and current_app.config.get("RESTX_ERROR_404_HELP", True)
             and include_message_in_response
         ):
             data["message"] = self._help_on_404(data.get("message", None))
