@@ -66,6 +66,10 @@ def is_indexable_but_not_string(obj):
     return not hasattr(obj, "strip") and hasattr(obj, "__iter__")
 
 
+def is_integer_indexable(obj):
+    return isinstance(obj, list) or isinstance(obj, tuple)
+
+
 def get_value(key, obj, default=None):
     """Helper for pulling a keyed value off various types of objects"""
     if isinstance(key, int):
@@ -91,6 +95,11 @@ def _get_value_for_key(key, obj, default):
             return obj[key]
         except (IndexError, TypeError, KeyError):
             pass
+    if is_integer_indexable(obj):
+        try:
+            return obj[int(key)]
+        except (IndexError, TypeError, ValueError):
+            pass
     return getattr(obj, key, default)
 
 
@@ -156,7 +165,7 @@ class Raw(object):
         self.description = description
         self.required = required
         self.readonly = readonly
-        self.example = example or self.__schema_example__
+        self.example = example if example is not None else self.__schema_example__
         self.mask = mask
 
     def format(self, value):
@@ -459,7 +468,7 @@ class Integer(NumberMixin, Raw):
             if value is None:
                 return self.default
             return int(value)
-        except ValueError as ve:
+        except (ValueError, TypeError) as ve:
             raise MarshallingError(ve)
 
 
@@ -473,7 +482,7 @@ class Float(NumberMixin, Raw):
     def format(self, value):
         try:
             return float(value)
-        except ValueError as ve:
+        except (ValueError, TypeError) as ve:
             raise MarshallingError(ve)
 
 
